summaryrefslogtreecommitdiffstats
path: root/content/browser/tab_contents/interstitial_page_impl.cc
diff options
context:
space:
mode:
authordarin@chromium.org <darin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-12 01:11:25 +0000
committerdarin@chromium.org <darin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-12 01:11:25 +0000
commitea114727620483755ebecf7b3fe4e7f9d50316e4 (patch)
tree4731c05242dc6745d2a7e9fb50e1e310470c7138 /content/browser/tab_contents/interstitial_page_impl.cc
parent0535866266fe81c93349f9abf0d2e2b87519b3d0 (diff)
downloadchromium_src-ea114727620483755ebecf7b3fe4e7f9d50316e4.zip
chromium_src-ea114727620483755ebecf7b3fe4e7f9d50316e4.tar.gz
chromium_src-ea114727620483755ebecf7b3fe4e7f9d50316e4.tar.bz2
Add content/public/browser/resource_dispatcher_host.h
R=jam@chromium.org TBR=willchan@chromium.org,mirandac@chromium.org,ben@chromium.org Review URL: https://chromiumcodereview.appspot.com/9648020 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@126089 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/browser/tab_contents/interstitial_page_impl.cc')
-rw-r--r--content/browser/tab_contents/interstitial_page_impl.cc22
1 files changed, 10 insertions, 12 deletions
diff --git a/content/browser/tab_contents/interstitial_page_impl.cc b/content/browser/tab_contents/interstitial_page_impl.cc
index a01cbf5..9186bc3 100644
--- a/content/browser/tab_contents/interstitial_page_impl.cc
+++ b/content/browser/tab_contents/interstitial_page_impl.cc
@@ -14,7 +14,7 @@
#include "base/utf_string_conversions.h"
#include "content/browser/renderer_host/render_process_host_impl.h"
#include "content/browser/renderer_host/render_view_host_impl.h"
-#include "content/browser/renderer_host/resource_dispatcher_host.h"
+#include "content/browser/renderer_host/resource_dispatcher_host_impl.h"
#include "content/browser/site_instance_impl.h"
#include "content/browser/tab_contents/navigation_controller_impl.h"
#include "content/browser/tab_contents/navigation_entry_impl.h"
@@ -48,6 +48,7 @@ using content::RenderWidgetHost;
using content::RenderWidgetHostImpl;
using content::RenderWidgetHostView;
using content::RenderWidgetHostViewPort;
+using content::ResourceDispatcherHostImpl;
using content::SiteInstance;
using content::WebContents;
using content::WebContentsView;
@@ -56,22 +57,19 @@ using WebKit::WebDragOperationsMask;
namespace {
-void ResourceRequestHelper(ResourceDispatcherHost* resource_dispatcher_host,
+void ResourceRequestHelper(ResourceDispatcherHostImpl* rdh,
int process_id,
int render_view_host_id,
ResourceRequestAction action) {
switch (action) {
case BLOCK:
- resource_dispatcher_host->BlockRequestsForRoute(
- process_id, render_view_host_id);
+ rdh->BlockRequestsForRoute(process_id, render_view_host_id);
break;
case RESUME:
- resource_dispatcher_host->ResumeBlockedRequestsForRoute(
- process_id, render_view_host_id);
+ rdh->ResumeBlockedRequestsForRoute(process_id, render_view_host_id);
break;
case CANCEL:
- resource_dispatcher_host->CancelBlockedRequestsForRoute(
- process_id, render_view_host_id);
+ rdh->CancelBlockedRequestsForRoute(process_id, render_view_host_id);
break;
default:
NOTREACHED();
@@ -649,11 +647,11 @@ void InterstitialPageImpl::TakeActionOnResourceDispatcher(
// The tab might not have a render_view_host if it was closed (in which case,
// we have taken care of the blocked requests when processing
// NOTIFY_RENDER_WIDGET_HOST_DESTROYED.
// Also we need to test there is a ResourceDispatcherHost, as when unit-tests
// we don't have one.
RenderViewHostImpl* rvh = RenderViewHostImpl::FromID(original_child_id_,
original_rvh_id_);
- if (!rvh || !ResourceDispatcherHost::Get())
+ if (!rvh || !ResourceDispatcherHostImpl::Get())
return;
BrowserThread::PostTask(
@@ -661,7 +659,7 @@ void InterstitialPageImpl::TakeActionOnResourceDispatcher(
FROM_HERE,
base::Bind(
&ResourceRequestHelper,
- ResourceDispatcherHost::Get(),
+ ResourceDispatcherHostImpl::Get(),
original_child_id_,
original_rvh_id_,
action));
@@ -649,11 +647,11 @@ void InterstitialPageImpl::TakeActionOnResourceDispatcher(
// we have taken care of the blocked requests when processing
// NOTIFY_RENDER_WIDGET_HOST_DESTROYED.
- // Also we need to test there is a ResourceDispatcherHost, as when unit-tests
- // we don't have one.
+ // Also we need to test there is a ResourceDispatcherHostImpl, as when unit-
+ // tests we don't have one.
RenderViewHostImpl* rvh = RenderViewHostImpl::FromID(original_child_id_,
original_rvh_id_);